summaryrefslogtreecommitdiffstats
path: root/c/src/lib/libbsp/sh/simsh4
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>2008-08-31 16:47:17 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>2008-08-31 16:47:17 +0000
commit424ee2ba6a59e0e7fdd05fb5ab7a0ee3843c8ddd (patch)
treeadad3c0933c2288b99c89e4aaf9c85a62371ca30 /c/src/lib/libbsp/sh/simsh4
parent2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com> (diff)
downloadrtems-424ee2ba6a59e0e7fdd05fb5ab7a0ee3843c8ddd.tar.bz2
2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com>
* timer/timer.c: Rename timer driver methods to follow RTEMS programming conventions.
Diffstat (limited to 'c/src/lib/libbsp/sh/simsh4')
-rw-r--r--c/src/lib/libbsp/sh/simsh4/ChangeLog5
-rw-r--r--c/src/lib/libbsp/sh/simsh4/timer/timer.c24
2 files changed, 17 insertions, 12 deletions
diff --git a/c/src/lib/libbsp/sh/simsh4/ChangeLog b/c/src/lib/libbsp/sh/simsh4/ChangeLog
index aff73c36b5..1dfae5e7f5 100644
--- a/c/src/lib/libbsp/sh/simsh4/ChangeLog
+++ b/c/src/lib/libbsp/sh/simsh4/ChangeLog
@@ -1,3 +1,8 @@
+2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com>
+
+ * timer/timer.c: Rename timer driver methods to follow RTEMS
+ programming conventions.
+
2008-08-27 Ralf Corsépius <ralf.corsepius@rtems.org>
* timer/timer.c: Eliminate rtems_boolean.
diff --git a/c/src/lib/libbsp/sh/simsh4/timer/timer.c b/c/src/lib/libbsp/sh/simsh4/timer/timer.c
index cdbfa051b3..a261df3860 100644
--- a/c/src/lib/libbsp/sh/simsh4/timer/timer.c
+++ b/c/src/lib/libbsp/sh/simsh4/timer/timer.c
@@ -22,12 +22,12 @@
uint32_t Timer_interrupts;
-bool Timer_driver_Find_average_overhead;
+bool benchmark_timerfind_average_overhead;
/* External assembler interrupt handler routine */
extern rtems_isr timerisr(rtems_vector_number vector);
-/* Timer_initialize --
+/* benchmark_timerinitialize --
* Initialize timer 2 for accurate time measurement.
*
* PARAMETERS:
@@ -37,13 +37,13 @@ extern rtems_isr timerisr(rtems_vector_number vector);
* none
*/
void
-Timer_initialize(void)
+benchmark_timerinitialize(void)
{
return;
}
/*
* The following controls the behavior of Read_timer().
*
* FIND_AVG_OVERHEAD * instructs the routine to return the "raw" count.
*
@@ -59,7 +59,7 @@ Timer_initialize(void)
/* This value is in microseconds. */
#define LEAST_VALID 1 /* Don't trust a clicks value lower than this */
-/* Read_timer --
+/* benchmark_timerread --
* Read timer value in microsecond units since timer start.
*
* PARAMETERS:
@@ -69,12 +69,12 @@ Timer_initialize(void)
* number of microseconds since timer has been started
*/
int
-Read_timer( void )
+benchmark_timerread( void )
{
return 0;
}
-/* Empty_function --
+/* benchmark_timerempty_function --
* Empty function call used in loops to measure basic cost of looping
* in Timing Test Suite.
*
@@ -85,14 +85,14 @@ Read_timer( void )
* RTEMS_SUCCESSFUL
*/
rtems_status_code
-Empty_function(void)
+benchmark_timerempty_function(void)
{
return RTEMS_SUCCESSFUL;
}
-/* Set_find_average_overhead --
+/* benchmark_timerdisable_subtracting_average_overhead --
* This routine is invoked by the "Check Timer" (tmck) test in the
* RTEMS Timing Test Suite. It makes the Read_timer routine not
* subtract the overhead required to initialize and read the benchmark
* timer.
*
@@ -103,7 +103,7 @@ Empty_function(void)
* none
*/
void
-Set_find_average_overhead(bool find_flag)
+benchmark_timerdisable_subtracting_average_overhead(bool find_flag)
{
- Timer_driver_Find_average_overhead = find_flag;
+ benchmark_timerfind_average_overhead = find_flag;
}
@@ -37,13 +37,13 @@ extern rtems_isr timerisr(rtems_vector_number vector);
}
/*
- * The following controls the behavior of Read_timer().
+ * The following controls the behavior of benchmark_timerread().
*
* FIND_AVG_OVERHEAD * instructs the routine to return the "raw" count.
@@ -85,14 +85,14 @@ Read_timer( void )
* This routine is invoked by the "Check Timer" (tmck) test in the
- * RTEMS Timing Test Suite. It makes the Read_timer routine not
+ * RTEMS Timing Test Suite. It makes the benchmark_timerread routine not
* subtract the overhead required to initialize and read the benchmark
* timer.